SystemOrganization addCategory: #'OB-Tests-Standard'!

BogusTestCase subclass: #OBActorTest
	instanceVariableNames: 'notification announcer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBActorTest class methodsFor: 'testing' stamp: ''!
isAbstract
	^ self name = #OBActorTest! !

!OBActorTest methodsFor: 'fetching' stamp: 'cwp 6/4/2006 00:33'!
actionNamed: aName forNode: aNode
	| action |
	action := (self actor actionsForNode: aNode) 
				detect: [:ea | ea label = aName].
	action announcer: self announcer.
	^ action! !

!OBActorTest methodsFor: 'fetching' stamp: 'cwp 6/4/2006 00:33'!
actionNamed: aName forParent: aNode
	| action |
	action := (self actor actionsForParent: aNode) 
				detect: [:ea | ea label = aName].
	action announcer: self announcer.
	^ action! !

!OBActorTest methodsFor: 'emulating' stamp: 'cwp 6/5/2006 01:02'!
announcer
	^ announcer! !

!OBActorTest methodsFor: 'asserting' stamp: ''!
assertActions: actions includeLabels: expected
	| actual |
	actual := actions collect: [:ea | ea label].
	self assert: (actual includesAllOf: expected)
	! !

!OBActorTest methodsFor: 'constants' stamp: ''!
classCatNode
	^ OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk! !

!OBActorTest methodsFor: 'constants' stamp: 'dvf 8/31/2005 13:17'!
classNode
	^(Smalltalk at: #BogusA) asNode! !

!OBActorTest methodsFor: 'constants' stamp: ''!
envNode
	^ OBEnvironmentNode forImage! !

!OBActorTest methodsFor: 'constants' stamp: ''!
methCatNode
	^ OBMethodCategoryNode on: 'letters' inClass: BogusA! !

!OBActorTest methodsFor: 'constants' stamp: ''!
nodeLabels
	^ #()! !

!OBActorTest methodsFor: 'constants' stamp: ''!
parentLabels
	^ #()! !

!OBActorTest methodsFor: 'running' stamp: 'cwp 6/5/2006 01:02'!
setUp
	super setUp.
	announcer _ OBAnnouncer new.! !

!OBActorTest methodsFor: 'tests' stamp: ''!
testNodeLabels
	| actions |
	actions := self actor actionsForNode: self selectedNode.
	self assertActions: actions includeLabels: self nodeLabels
	! !

!OBActorTest methodsFor: 'tests' stamp: ''!
testParentLabels
	| actions |
	actions := self actor actionsForParent: self parentNode.
	self assertActions: actions includeLabels: self parentLabels! !

OBActorTest subclass: #OBCategoryActorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCategoryActorTest methodsFor: 'constants' stamp: 'cwp 9/20/2005 08:45'!
actor
	^ OBCategoryActor new
		! !

!OBCategoryActorTest methodsFor: 'emulation' stamp: 'cwp 9/23/2005 22:38'!
definition: aDefinition
	self assert: aDefinition notNil.
	self assert: aDefinition text = self organization. ! !

!OBCategoryActorTest methodsFor: 'constants' stamp: ''!
nodeLabels
	^ #('remove' 'rename...').! !

!OBCategoryActorTest methodsFor: 'constants' stamp: 'cwp 11/7/2004 00:06'!
organization
	^  '(''letters'' a b)
(''numbers'' five one three two)
(''other'' bogusHopefullyUniqueSelector bogusOtherUniqueSelector isString)
(''*bogusext'' foo)
(''*bogusext-testing'' isFake)
'! !

!OBCategoryActorTest methodsFor: 'constants' stamp: 'cwp 9/22/2004 20:59'!
parentLabels
	^ #('create category...' 
		'alphabetize categories' 
		'remove empty categories' 
		'categorize automatically'
		'reorganize categories').! !

!OBCategoryActorTest methodsFor: 'constants' stamp: ''!
parentNode
	^ self classNode! !

!OBCategoryActorTest methodsFor: 'constants' stamp: ''!
selectedNode
	^ self classCatNode! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 2/28/2006 17:18'!
testCategorizeAll
	| classify |
	BogusA organization classify: #beep under: (ClassOrganizer default).
	damage add: #Categories ofClass: #BogusA.
	classify := self actionNamed: 'categorize automatically' forParent: self classNode.
	classify trigger.
	self deny: (BogusA organization categories includes: (ClassOrganizer default)).
	self assert: (BogusA organization categoryOfElement: #beep) 
					= (Object organization categoryOfElement: #beep).
	BogusA organization removeElement: #beep	! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/23/2004 23:26'!
testCreateClassCat
	| remove |
	remove := self actionNamed: 'create category...' forParent: self envNode.
	[remove trigger]
		on: OBTextRequest
		do: [:n | self assert: n template = 'Category-Name']! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/23/2004 23:24'!
testCreateMethodCat
	| remove |
	remove := self actionNamed: 'create category...' forParent: self classNode.
	[remove trigger]
		on: OBTextRequest
		do: [:n | self assert: n template = 'category name'.
				n resume: 'zletters'].
	damage add: #Categories ofClass: #BogusA.
	self assert: (BogusA organization categories includes: #zletters)! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/20/2005 08:13'!
testNoSystemAutoCat
	| action |
	action := (self actor actionsForParent: self envNode) 
				detect: [:ea | ea label = 'categorize automatically'] ifNone: [nil].
	self assert: action isNil! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/18/2004 21:47'!
testRemoveEmptyMethodCats
	| remove |
	BogusA  organization addCategory: #zletters.
	damage add: #Categories ofClass: #BogusA.
	remove := self actionNamed: 'remove empty categories' forParent: self classNode.
	remove trigger.
	self deny: (BogusA organization categories includes: #zletters)! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/17/2004 00:39'!
testRemoveMethodCat
	| remove |
	remove := self actionNamed: 'remove' forNode: self methCatNode.
	[remove trigger]
		on: OBConfirmationRequest
		do: [:n | n resume: true].
	damage add: #a ofClass: #BogusA.
	damage add: #b ofClass: #BogusA.
	self deny: (BogusA organization categories includes: #letters)! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/17/2004 00:39'!
testRenameMethodCat
	| rename |
	rename := self actionNamed: 'rename...' forNode: self methCatNode.
	[rename trigger]
		on: OBTextRequest
		do: [:n | n resume: 'zletters'].
	damage add: #Categories ofClass: #BogusA.
	self deny: (BogusA organization categories includes: #letters).
	self assert: (BogusA organization categories includes: #zletters)! !

!OBCategoryActorTest methodsFor: 'tests' stamp: 'cwp 9/23/2005 22:37'!
testReorganize
	| action |
	action := self actionNamed: 'reorganize categories' forParent: self classNode.
	action trigger.
! !

!OBCategoryActorTest methodsFor: 'tests' stamp: ''!
testSortMethodCats
	| remove |
	BogusA organization addCategory: 'zzz' before: BogusA organization categories first.
	remove := self actionNamed: 'alphabetize categories' forParent: self classNode.
	remove trigger.
	damage add: #Categories ofClass: #BogusA.
	self assert: BogusA organization categories = BogusA organization categories asSortedArray! !

OBActorTest subclass: #OBClassActorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBClassActorTest methodsFor: 'constants' stamp: ''!
actor
	^ OBClassActor new! !

!OBClassActorTest methodsFor: 'asserting' stamp: 'cwp 11/16/2004 23:43'!
assertCorrectBrowser: aBrowser
	self assert: (aBrowser isKindOf: OBListBrowser)! !

!OBClassActorTest methodsFor: 'constants' stamp: 'dvf 8/31/2005 13:17'!
classFNode
	^(Smalltalk at: #BogusF) asNode! !

!OBClassActorTest methodsFor: 'emulating' stamp: 'cwp 9/23/2005 22:49'!
definition: aDefinition
	self assert: aDefinition notNil.
	self assert: aDefinition text = self subclassTemplate. ! !

!OBClassActorTest methodsFor: 'constants' stamp: 'cwp 9/16/2004 15:24'!
nodeLabels
	^ #('remove' 'rename...' 'copy...' 'subclass template')! !

!OBClassActorTest methodsFor: 'constants' stamp: 'dvf 8/31/2005 13:17'!
ownClassNode
	^(Smalltalk at: self class name) asNode! !

!OBClassActorTest methodsFor: 'constants' stamp: ''!
parentLabels
	^ #()! !

!OBClassActorTest methodsFor: 'constants' stamp: ''!
parentNode
	^ self classCatNode! !

!OBClassActorTest methodsFor: 'constants' stamp: ''!
selectedNode
	^ self classNode! !

!OBClassActorTest methodsFor: 'constants' stamp: 'cwp 9/14/2005 23:06'!
subclassTemplate
	^  'BogusA subclass: #NameOfSubclass
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''Bogus-Base'''! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 10/17/2004 20:10'!
testCopy
	| rename |
	damage add: #Definition ofClass: #BogusF.
	damage add: #Definition ofClass: #BogusX.
	rename := self actionNamed: 'copy...' forNode: self classFNode.
	[rename trigger]
		on: OBTextRequest
		do: [:n | n resume: 'BogusX'].
	self assert: (Smalltalk hasClassNamed: #BogusF).
	self assert: (Smalltalk hasClassNamed: #BogusX)! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 12/2/2004 23:14'!
testReferences
	| remove |
	remove := self actionNamed: 'browse references' forNode: self classFNode.
	[remove trigger]
		on: OBBrowseRequest
		do: [:n | self assertCorrectBrowser: n browser].
! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 10/17/2004 20:10'!
testRemove
	| remove |
	damage add: #Definition ofClass: #BogusF.
	remove := self actionNamed: 'remove' forNode: self classFNode.
	[remove trigger]
		on: OBConfirmationRequest
		do: [:n | n resume: true].
	self deny: (Smalltalk hasClassNamed: #BogusF)! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 10/17/2004 22:35'!
testRename
	| rename |
	damage addRenameOf: #BogusF to: #BogusX.
	rename := self actionNamed: 'rename...' forNode: self classFNode.
	[rename trigger]
		on: OBInteractionRequest
		do: [:n | n resume: 'BogusX'].
	self deny: (Smalltalk hasClassNamed: #BogusF).
	self assert: (Smalltalk hasClassNamed: #BogusX)! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 12/2/2004 22:43'!
testRenameNoReferences
	| rename newName |
	newName := self class name, 'X'.
	damage addRenameOf: self class name to: newName asSymbol.
	rename := self actionNamed: 'rename...' forNode: self ownClassNode.
	self 
		shouldnt: [[rename trigger] 
					on: OBTextRequest
					do: [:n | n resume: newName]]
		raise: OBBrowseRequest.
! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 11/30/2004 22:13'!
testRenamedReferences
	| rename raised |
	damage addRenameOf: #BogusA to: #BogusX.
	raised _ false.
	rename := self actionNamed: 'rename...' forNode: self classNode.
	[rename trigger] 
		on: OBTextRequest, OBBrowseRequest
		do: [:n | n isBrowseRequest	
					ifTrue: [self assertCorrectBrowser: n browser.
							raised _ true]
					ifFalse: [n resume: 'BogusX']].
	self assert: raised.! !

!OBClassActorTest methodsFor: 'tests' stamp: 'cwp 9/23/2005 22:49'!
testSubclassTemplate
	| action |
	action := self actionNamed: 'subclass template' forNode: self classNode.
	action trigger.! !

BogusTestCase subclass: #OBOrganizationDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBOrganizationDefinitionTest methodsFor: 'constants' stamp: 'cwp 9/22/2004 22:08'!
definition
	^ OBOrganizationDefinition on: BogusA organization! !

!OBOrganizationDefinitionTest methodsFor: 'constants' stamp: 'cwp 11/6/2004 23:18'!
newOrgText
	^ '(''alphanum'' a b five one three two)
(''other'' bogusHopefullyUniqueSelector bogusOtherUniqueSelector isString)
(''*bogusext'' foo)
(''*bogusext-testing'' isFake)
'
! !

!OBOrganizationDefinitionTest methodsFor: 'constants' stamp: 'cwp 11/6/2004 23:17'!
orgText
	^ '(''letters'' a b)
(''numbers'' five one three two)
(''other'' bogusHopefullyUniqueSelector bogusOtherUniqueSelector isString)
(''*bogusext'' foo)
(''*bogusext-testing'' isFake)
'! !

!OBOrganizationDefinitionTest methodsFor: 'tests' stamp: 'cwp 6/5/2006 00:19'!
testAccept
	| definition |
	damage add: #Categories ofClass: #BogusA.
	definition _ self definition.
	definition accept: self newOrgText notifying: self.
	self assert: definition text = self newOrgText.
	self assert: BogusA organization asString = self newOrgText! !

!OBOrganizationDefinitionTest methodsFor: 'tests' stamp: 'cwp 9/22/2004 22:31'!
testDisplay
	self assert: self definition text = self orgText! !

OBBrowserTest subclass: #OBAccessBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBAccessBrowserTest methodsFor: 'configuration' stamp: 'avi 9/17/2005 01:39'!
browserClass
	^ OBVariablesBrowser! !

!OBAccessBrowserTest methodsFor: 'configuration' stamp: 'dvf 8/31/2005 13:17'!
node
	^BogusB asNode! !

!OBAccessBrowserTest methodsFor: 'testing' stamp: ''!
testInitalDisplay
	self assertListAt: 1 contains: BogusInfo bInstVarNames! !

!OBAccessBrowserTest methodsFor: 'testing' stamp: 'cwp 9/13/2005 21:39'!
testSelectCVar
	self clickButtonLabeled: 'class'.
	self select: 'FirstClassVariableB'.
	self assertListAt: 2 contains: #('BogusB>>accessesCVar' 
								   'BogusB class>>accessesCVarAlso'
								   'BogusB>>foreign2')! !

!OBAccessBrowserTest methodsFor: 'testing' stamp: ''!
testSelectIVarAccessor
	self select: 'firstInstanceVariableB'.
	self select: 'BogusB>>accessesIvar'.
	self assertListAt: 3 includes: #('BogusB>>sendsAccessesIvar')! !

!OBAccessBrowserTest methodsFor: 'testing' stamp: 'cwp 9/13/2005 21:38'!
testSelectIvar
	self select: 'firstInstanceVariableB'.
	self assertListAt: 2 contains: #('BogusB>>accessesIvar' 'BogusB>>foreign')! !

!OBAccessBrowserTest methodsFor: 'testing' stamp: ''!
testSelectSender
	self select: 'firstInstanceVariableB'.
	self select: 'BogusB>>accessesIvar'.
	self select: 'BogusB>>sendsAccessesIvar'.
	self assertListAt: 4 contains: #('BogusB>>sendsSendsAccessesIvar')
! !

OBBrowserTest subclass: #OBChasingBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBChasingBrowserTest class methodsFor: 'as yet unclassified' stamp: 'cwp 12/8/2004 22:59'!
isAbstract
	^ self name = #OBChasingBrowserTest! !

!OBChasingBrowserTest methodsFor: 'tests' stamp: 'cwp 12/8/2004 23:03'!
testChaseDisplay
	self clickButtonLabeled: 'chase'.
	self 
		assertListAt: 1 
		contains: self initialList! !

!OBChasingBrowserTest methodsFor: 'tests' stamp: 'cwp 12/8/2004 22:58'!
testInitialDisplay
	self 
		assertListAt: 1 
		contains: self initialList! !

OBChasingBrowserTest subclass: #OBImplementorsBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBImplementorsBrowserTest methodsFor: 'configuration' stamp: 'avi 9/17/2005 01:40'!
browserClass
	^ OBImplementorsBrowser! !

!OBImplementorsBrowserTest methodsFor: 'configuration' stamp: 'cwp 12/8/2004 23:37'!
initialList
	^ #('BogusB>>sendsSendsAccessesIvar')! !

!OBImplementorsBrowserTest methodsFor: 'configuration' stamp: 'cwp 12/8/2004 23:37'!
node
	"We don't want this method to show up in senders 
	of #sendsSendsAccesses, since other tests 
	aren't expecting it."
	
	| selector |
	selector := ('sendsSendsAccesses', 'Ivar') asSymbol.
	^ OBMethodNode on: selector inClass: BogusB! !

!OBImplementorsBrowserTest methodsFor: 'tests' stamp: 'cwp 12/8/2004 23:41'!
testMessagesOf
	self clickButtonLabeled: 'chase'.
	self select: 'BogusB>>sendsSendsAccessesIvar'.
	self assertListAt: 2 contains: #('sendsAccessesIvar')! !

OBChasingBrowserTest subclass: #OBSendersBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSendersBrowserTest methodsFor: 'configuration' stamp: 'avi 9/17/2005 01:40'!
browserClass
	^ OBSendersBrowser! !

!OBSendersBrowserTest methodsFor: 'configuration' stamp: 'cwp 12/8/2004 22:59'!
initialList
	^  #('BogusB>>sendsAccessesIvar')! !

!OBSendersBrowserTest methodsFor: 'configuration' stamp: 'cwp 12/8/2004 22:44'!
node
	"We don't want this method to show up in senders 
	of #accessesIvar, since that's what we're testing"
	
	| selector |
	selector := ('accesses', 'Ivar') asSymbol.
	^ OBMethodNode on: selector inClass: BogusB! !

!OBSendersBrowserTest methodsFor: 'tests' stamp: 'cwp 12/8/2004 23:15'!
testSendersOf
	self clickButtonLabeled: 'chase'.
	self select: 'BogusB>>sendsAccessesIvar'.
	self assertListAt: 2 contains: #('BogusB>>sendsSendsAccessesIvar')! !

OBBrowserTest subclass: #OBCodeBrowserTest
	instanceVariableNames: 'damage'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCodeBrowserTest class methodsFor: 'as yet unclassified' stamp: ''!
isAbstract
	^ self name = #OBCodeBrowserTest! !

!OBCodeBrowserTest class methodsFor: 'as yet unclassified' stamp: ''!
resources
	^ Array with: BogusSnapshotResource! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
altMethodA
	^ 'a
	^ $B'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
altMethodOne
	^ 'one
	^ 11'! !

!OBCodeBrowserTest methodsFor: 'asserting' stamp: ''!
assertIsClassSide
	self assertButtonSelected: 'class'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
bogusAClassTemplate
	^  'BogusA class
	instanceVariableNames: '''''! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:51'!
bogusAName
	^'BogusA'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
bogusATemplate
	^ 'Object subclass: #BogusA
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	package: ''', BogusInfo packageName, '''
	category: ''Base'''! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
bogusBComment
	^ 'A comment for BogusB'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
bogusCDefinition
 ^ 'Object subclass: #BogusC
	instanceVariableNames: ''foo''
	classVariableNames: ''''
	poolDictionaries: ''''
	package: ''', self bogusPackageName, '''
	category: ''Base'''! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:40'!
bogusCategoryName
	^ BogusInfo baseCategory! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: 'cwp 12/10/2004 21:15'!
bogusClassNames
	^BogusInfo baseClassNames! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
bogusDDefinition
 ^ 'Object subclass: #BogusD
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	package: ''', BogusInfo packageName, '''
	category: ''Base'''! !

!OBCodeBrowserTest methodsFor: 'running' stamp: ''!
browserResource
	^ self class resources first current! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
classTemplate
	^ 'Object subclass: #NameOfSubclass
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	package: ''', BogusInfo packageName, '''
	category: ''Base'''! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: ''!
deselectBogusCategory
	self deselect: self bogusCategoryName! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeAClassTemplate
	^  self deprecated: 'Use #bogusAClassTemplate'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeAComment
	self deprecated: 'Use BogusInfo>>aComment instead'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeATemplate
	self deprecated: 'Use #bogusATemplate instead'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeClassBComment
	self deprecated: 'Use #bogusBComment'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeClassCDefinition
	self deprecated: 'Use #bogusCDefinition'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakeClassDDefinition
	self deprecated: 'Use #bogusDDefinition'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
fakePackageName
	self deprecated: 'Use BogusInfo>>packageName'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
methodA
	^ 'a
	^ $A'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
methodFour
	^ 'four
	^ 4'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
methodOne
	^ 'one
	^ 1'! !

!OBCodeBrowserTest methodsFor: 'constants' stamp: ''!
methodTemplate
	^ 'message selector and argument names
	"comment stating purpose of message"

	| temporary variable names |
	statements'! !

!OBCodeBrowserTest methodsFor: 'running' stamp: 'cwp 3/1/2006 19:52'!
runCase
	SystemChangeNotifier uniqueInstance doSilently: [super runCase]! !

!OBCodeBrowserTest methodsFor: 'running' stamp: 'cwp 3/1/2006 19:52'!
runCaseAsFailure: aSemaphore
	SystemChangeNotifier uniqueInstance doSilently: [super runCaseAsFailure: aSemaphore]! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: 'cwp 12/13/2004 00:01'!
selectBogusA
	self select: self bogusAName! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: ''!
selectBogusCategory
	self select: self bogusCategoryName! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: ''!
selectBogusPackage
	! !

!OBCodeBrowserTest methodsFor: 'running' stamp: 'cwp 12/10/2004 21:32'!
setUp
	damage := BogusDamage new.
	model _ self browserClass metaNode: self metagraph node: self node.
	morph _ model morph.
	self forceLayout! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: ''!
switchToClassSide
	self clickButtonLabeled: 'class'! !

!OBCodeBrowserTest methodsFor: 'simulating' stamp: ''!
switchToComment
	self clickButtonLabeled: '?'! !

!OBCodeBrowserTest methodsFor: 'running' stamp: ''!
tearDown
	damage repair! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:01'!
testButtonRemoval
	self selectBogusCategory.
	self selectBogusA.
	self deselectBogusCategory.
	self assertNoButtonsVisible! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:26'!
testColumnClearing
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self select: 'one'.
	self switchToClassSide.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('testing' 'capitals').
	self denyAListIncludes: #('letters' 'numbers').
	self denyAListIncludes: #('one' 'two' 'three').
	self assertTextIs: self bogusAClassTemplate! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: ''!
testCreateClassFromClass
	self selectBogusCategory.
	self select: 'BogusC'.
	self setText: self bogusDDefinition.
	damage add: #Definition ofClass: #BogusD.
	self assertAListIncludes: #(BogusD).
	self assertCurrentItemIs: #BogusD.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:09'!
testCreateClassFromTemplate
	self selectBogusCategory.
	damage add: #Definition ofClass: #BogusD.
	self setText: self bogusDDefinition.
	self assertAListIncludes: #(BogusD).
	self assertCurrentItemIs: #BogusD ! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/20/2004 00:37'!
testCreateMethodFromMethod
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self select: 'one'.
	damage add: #four ofClass: #BogusA.
	self setText: self methodFour.
	self assertAListMatches: #('one' 'two' 'three' 'four' 'five').
	self assertCurrentItemIs: 'four' 
! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:04'!
testCreateMethodFromTemplate
	self selectBogusCategory.
	self selectBogusA.
	self select: 'letters'.
	self setText: self methodFour.
	damage add: #four ofClass: #BogusA.
	self assertAListMatches: #('a' 'b' 'four').
	self assertCurrentItemIs: 'four' 
! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:04'!
testDeselectFakeA
	self selectBogusCategory.
	self selectBogusA.
	self deselect: self bogusAName.
	self assertAListIncludes: {self bogusCategoryName}.
	self assertAListIncludes: self bogusClassNames.
	self denyAListIncludes: #('letters' 'numbers').
	self assertTextIs: self classTemplate.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/10/2004 23:46'!
testEditClass
	self selectBogusCategory.
	self select: 'BogusC'.
	self setText: self bogusCDefinition.
	damage add: #Definition ofClass: #BogusC.
	self assertAListIncludes: self bogusClassNames.
	self assertCurrentItemIs: #BogusC.
	self assert: BogusC instVarNames = #(foo)! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:04'!
testEditClassMethod
	self selectBogusCategory.
	self selectBogusA.
	self switchToClassSide.
	self select: 'capitals'.
	self select: 'a'.
	self setText: self altMethodA.
	damage add: #a ofClass: #BogusA isMeta: true.
	self assertAListMatches: #('a' 'b').
	self assertCurrentItemIs: 'a'.
	self assert: $B = BogusA a! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/15/2004 21:06'!
testEditComment
	self selectBogusCategory.
	self selectBogusA.
	self switchToComment.
	self setText: self bogusBComment.
	damage add: #Comment ofClass: #BogusA.
	self assertAListIncludes: self bogusClassNames.
	self assertCurrentItemIs: #BogusA.
	self assert: BogusA comment = self bogusBComment! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:04'!
testEditMethod
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self select: 'one'.

	damage add: #one ofClass: #BogusA.
	self setText: self altMethodOne.
	self assertAListMatches: #('one' 'two' 'three' 'five').
	self assertCurrentItemIs: 'one'.
	self assert: 11 = BogusA new one! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'dvf 8/31/2005 13:14'!
testJumpToBogusA
	self selectBogusPackage.
	model jumpTo: (BogusA asNode).
	self assertCurrentItemIs: self bogusAName! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: ''!
testJumpToCapitals
	self selectBogusPackage.
	model jumpTo: (OBMethodCategoryNode 
					on: 'capitals' 
					inClass: BogusA class).
	self assertCurrentItemIs: 'capitals'.
	self assertIsClassSide.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/12/2004 23:55'!
testJumpToFakes
	self selectBogusPackage.
	model jumpTo: (OBClassCategoryNode 
						on: self bogusCategoryName 
						inEnvironment: Smalltalk).
	self assertCurrentItemIs: self bogusCategoryName! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: ''!
testJumpToMethodOne
	self selectBogusPackage.
	model jumpTo: (OBMethodNode 
					on: #one 
					inClass: BogusA).
	self assertCurrentItemIs: 'one'! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: ''!
testJumpToNumbers
	self selectBogusPackage.
	model jumpTo: (OBMethodCategoryNode 
					on: 'numbers' 
					inClass: BogusA).
	self assertCurrentItemIs: 'numbers'.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 6/9/2006 23:08'!
testMethodChangedElsewhere
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self select: 'one'.
	self editText: 'foo'.

	damage add: #one ofClass: #BogusA.
	BogusA compile: self altMethodOne.
	model announcer announce: OBRefreshRequired new.

	self assertAListMatches: #('one' 'two' 'three' 'five').
	self assertCurrentItemIs: 'one'.
	self assert: self textMorph hasEditingConflicts
	! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:25'!
testSelectAllMethodCategory
	self selectBogusCategory.
	self selectBogusA.
	self select: '-- all --'.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('letters' 'numbers').
	self assertAListIncludes: #('one' 'two' 'three' 'five' 'a' 'b').
	self assertTextIs: self methodTemplate! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:26'!
testSelectBogusA
	self selectBogusCategory.
	self selectBogusA.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('letters' 'numbers').
	self assertCurrentItemIs: self bogusAName.
	self assertTextIs: self bogusATemplate! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:23'!
testSelectBogusAClassSide
	self selectBogusCategory.
	self selectBogusA.
	self switchToClassSide.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('capitals').
	self assertCurrentItemIs: self bogusAName.
	self assertTextIs: self bogusAClassTemplate! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:23'!
testSelectBogusAComment
	self selectBogusCategory.
	self selectBogusA.
	self switchToComment.
	self assertAListIncludes: self bogusClassNames.
	self denyAListIncludes: #('letters' 'numbers').
	self assertCurrentItemIs: self bogusAName.
	self assertTextIs: BogusInfo aComment.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/10/2004 21:16'!
testSelectCategory
	self selectBogusCategory.
	self assertAListIncludes: {self bogusCategoryName}.
	self assertAListIncludes: self bogusClassNames.
	self assertTextIs: self classTemplate! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:26'!
testSelectNumbers
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('letters' 'numbers').
	self assertAListIncludes: #('one' 'two' 'three').
	self assertTextIs: self methodTemplate.
	self assertTextIsSelected.! !

!OBCodeBrowserTest methodsFor: 'testing' stamp: 'cwp 12/13/2004 00:30'!
testSelectOne
	self selectBogusCategory.
	self selectBogusA.
	self select: 'numbers'.
	self select: 'one'.
	self assertAListIncludes: self bogusClassNames.
	self assertAListIncludes: #('letters' 'numbers').
	self assertAListIncludes: #('one' 'two' 'three').
	self assertTextIs: BogusInfo aOneSource! !

OBCodeBrowserTest subclass: #OBImageBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

OBImageBrowserTest subclass: #OBAltImageBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBAltImageBrowserTest methodsFor: 'constants' stamp: 'cwp 1/8/2005 11:39'!
bogusClassNames
	^ #('BogusA' 'BogusE' 'BogusB' 'BogusC')! !

!OBAltImageBrowserTest methodsFor: 'constants' stamp: 'avi 9/17/2005 01:12'!
metagraph
	^ OBSystemBrowser defaultMetaNode! !

OBImageBrowserTest subclass: #OBHierImageBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBHierImageBrowserTest class methodsFor: 'as yet unclassified' stamp: 'cwp 12/12/2004 23:32'!
shouldInheritSelectors
	^ true! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 1/8/2005 11:49'!
bogusAName
	^ 'BogusA'! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 1/8/2005 11:52'!
bogusClassNames
	^ #('ProtoObject' 'Object' 'BogusA' 'BogusE')! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/13/2004 00:11'!
bogusDDefinition
 ^ 'BogusA subclass: #BogusD
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 1/8/2005 12:07'!
bogusDName
	^ 'BogusD'! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/13/2004 00:31'!
bogusEDefinition
 ^ 'BogusA subclass: #BogusE
	instanceVariableNames: ''foo''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBHierImageBrowserTest methodsFor: 'constants' stamp: 'cwp 1/8/2005 12:05'!
bogusEName
	^ 'BogusE'! !

!OBHierImageBrowserTest methodsFor: 'set up' stamp: 'cwp 9/23/2005 23:08'!
metagraph
	^ OBHierarchyBrowser defaultMetaNode! !

!OBHierImageBrowserTest methodsFor: 'set up' stamp: 'dvf 8/31/2005 13:17'!
node
	^BogusA asNode! !

!OBHierImageBrowserTest methodsFor: 'simulating' stamp: 'cwp 12/12/2004 23:43'!
selectBogusCategory
	! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/13/2004 00:07'!
testButtonRemoval
	"Not applicable to hierarchy browser"! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/13/2004 00:33'!
testCreateClassFromClass
	self selectBogusCategory.
	self select: self bogusEName.
	damage add: #Definition ofClass: #BogusD.
	self setText: self bogusDDefinition.
	self assertAListIncludes: {self bogusDName}.
	self assertCurrentItemIs: self bogusDName.! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/13/2004 00:15'!
testCreateClassFromTemplate
	"doesn't apply for now"! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/13/2004 00:34'!
testDeselectFakeA
	self selectBogusCategory.
	self selectBogusA.
	self deselect: self bogusAName.
	self assertAListIncludes: self bogusClassNames.
	self denyAListIncludes: #('letters' 'numbers').
	self assertTextIs: '' "for now"! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/13/2004 00:30'!
testEditClass
	self selectBogusCategory.
	self select: self bogusEName.
	damage add: #Definition ofClass: #BogusE.
	self setText: self bogusEDefinition.
	self assertAListIncludes: self bogusClassNames.
	self assertCurrentItemIs: self bogusEName.
	self assert: BogusE instVarNames = #(foo)! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/15/2004 21:13'!
testEditComment
	self selectBogusCategory.
	self selectBogusA.
	self switchToComment.
	damage add: #Comment ofClass: #BogusA.
	self setText: self bogusBComment.
	self assertAListIncludes: self bogusClassNames.
	self assertCurrentItemIs: self bogusAName.
	self assert: BogusA comment = self bogusBComment! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/15/2004 21:13'!
testInitialDisplay
	self listMorphs size = 1.
	self assertListAt: 1 includes: self bogusClassNames.
	self assertTextIs: ''.! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/12/2004 23:24'!
testJumpToFakes
	"Not applicable to the hierarchy browser"! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'cwp 12/12/2004 23:44'!
testSelectCategory
	"Not applicable to the hierarchy browser"! !

!OBHierImageBrowserTest methodsFor: 'tests' stamp: 'dvf 9/5/2005 18:12'!
testSelectionPath
	self selectBogusCategory.
	self selectBogusA.
	model selectionPath = {OBClassCategoryNode on: self bogusCategoryName. OBClassNode on: self bogusAName} asOrderedCollection.! !

!OBImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:39'!
bogusATemplate
	^ 'Object subclass: #BogusA
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:39'!
bogusCDefinition
 ^ 'Object subclass: #BogusC
	instanceVariableNames: ''foo''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:39'!
bogusDDefinition
 ^ 'Object subclass: #BogusD
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBImageBrowserTest methodsFor: 'set up' stamp: 'cwp 12/10/2004 21:27'!
browserClass
	^ OBSystemBrowser! !

!OBImageBrowserTest methodsFor: 'constants' stamp: 'cwp 12/12/2004 23:40'!
classTemplate
	^ 'Object subclass: #NameOfSubclass
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', self bogusCategoryName, ''''! !

!OBImageBrowserTest methodsFor: 'set up' stamp: 'avi 9/17/2005 01:13'!
metagraph
	^ OBSystemBrowser alphabeticalMetaNode! !

!OBImageBrowserTest methodsFor: 'set up' stamp: 'cwp 12/10/2004 21:28'!
node
	^ OBEnvironmentNode forImage! !

!OBImageBrowserTest methodsFor: 'testing' stamp: 'cwp 12/12/2004 23:40'!
testInitialDisplay
	self listMorphs size = 1.
	self assertListAt: 1 includes: {self bogusCategoryName}.
	self assertTextIs: ''.
	! !

OBBrowserTest subclass: #OBInheritanceBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'cwp 12/8/2004 23:49'!
interiorNode
	^ OBMethodNode on: #isString inClass: BogusA! !

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'cwp 12/8/2004 23:49'!
leafNode
	^ OBMethodNode on: #isString inClass: BogusE! !

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'avi 9/17/2005 01:11'!
metagraph
	^ OBInheritanceBrowser defaultMetaNode! !

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'cwp 12/8/2004 23:49'!
rootNode
	^ OBCollectionNode on: {OBMethodNode 
								on: #isString 
								inClass: Object}! !

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'cwp 11/28/2004 10:22'!
setUp! !

!OBInheritanceBrowserTest methodsFor: 'running' stamp: 'cwp 12/5/2004 18:03'!
setUpWith: targetNode
	[OBInheritanceBrowser openRoot: self rootNode selection: targetNode]
		on: OBBrowseRequest
		do: [:notification | 
			model := notification browser.
			morph := model morph].
	self forceLayout.! !

!OBInheritanceBrowserTest methodsFor: 'testing' stamp: 'cwp 9/17/2005 18:09'!
testInitialDisplay
	self setUpWith: self interiorNode.
	self 
		assertListAt: 1 contains: #('Object>>isString');
		assertListAt: 2 contains: #('BogusA>>isString' 'String>>isString');
		assertListAt: 3 contains: #('BogusE>>isString');
		assertCurrentItemIs: 'BogusA>>isString'! !

!OBInheritanceBrowserTest methodsFor: 'testing' stamp: 'cwp 9/17/2005 18:09'!
testInitialDisplay2
	self setUpWith: self leafNode.
	self 
		assertListAt: 1 contains: #('Object>>isString');
		assertListAt: 2 contains: #('BogusA>>isString' 'String>>isString');
		assertListAt: 3 contains: #('BogusE>>isString');
		assertCurrentItemIs: 'BogusE>>isString'! !

OBBrowserTest subclass: #OBReferencesBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBReferencesBrowserTest methodsFor: 'constants' stamp: 'cwp 12/1/2004 01:18'!
bogusCReferences
	^ {	'OBCodeBrowserTest>>testEditClass'.
		'OBReferencesBrowserTest>>node'.
		'OBReferencesBrowserTest>>refersToBogusC' }! !

!OBReferencesBrowserTest methodsFor: 'configuration' stamp: 'avi 9/17/2005 01:43'!
browserClass
	^ OBReferencesBrowser! !

!OBReferencesBrowserTest methodsFor: 'configuration' stamp: 'dvf 8/31/2005 13:17'!
node
	^BogusC asNode! !

!OBReferencesBrowserTest methodsFor: 'bogus' stamp: 'cwp 12/1/2004 00:58'!
refersToBogusC
	^ BogusC! !

!OBReferencesBrowserTest methodsFor: 'tests' stamp: 'cwp 12/1/2004 00:32'!
testClassNameSelection
	self select: 'OBReferencesBrowserTest>>node'.
	self assertSelectedTextIs: 'BogusC'! !

!OBReferencesBrowserTest methodsFor: 'tests' stamp: 'cwp 11/30/2004 20:31'!
testInitialDisplay
	self assertListAt: 1 contains: self bogusCReferences! !

!OBReferencesBrowserTest methodsFor: 'tests' stamp: 'cwp 12/1/2004 01:09'!
testSelectorSelection
	self select: 'OBReferencesBrowserTest>>refersToBogusC'.
	self deny: self textMorph getSelection = (9 to: 13)! !

OBBrowserTest subclass: #OBVersionsBrowserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBVersionsBrowserTest methodsFor: 'constants' stamp: 'cwp 11/27/2004 21:43'!
expectedHeadings
	^ #('BogusA>>two cwp 3/11/2004 20:07' 'BogusA>>two cwp 3/11/2004 20:06' 'BogusA>>two cwp 3/11/2004 20:06' 'BogusA>>two cwp 3/11/2004 20:07' 'BogusA>>two cwp 3/11/2004 20:06' 'BogusA>>two cwp 3/11/2004 20:06')! !

!OBVersionsBrowserTest methodsFor: 'running' stamp: 'avi 9/17/2005 01:11'!
metagraph
	^ OBVersionBrowser defaultMetaNode! !

!OBVersionsBrowserTest methodsFor: 'running' stamp: ''!
node
	^ OBMethodNode on: #two inClass: BogusA! !

!OBVersionsBrowserTest methodsFor: 'running' stamp: 'cwp 12/5/2004 18:02'!
setUp
	(BogusA compiledMethodAt: #two) setSourcePointer: self twoSourcePointer.
	[OBVersionBrowser openOn: self node]
		on: OBBrowseRequest, OBSourceFilesRequest 
		do: [:notification |
			notification isBrowseRequest
				ifTrue: [model := notification browser.
						morph := model morph]
				ifFalse: [notification resume: self sourceFiles]].
	self forceLayout
		! !

!OBVersionsBrowserTest methodsFor: 'emulating' stamp: ''!
sourceFiles
	^ OBSourceFilesResource current sources! !

!OBVersionsBrowserTest methodsFor: 'running' stamp: ''!
tearDown
	(BogusA compiledMethodAt: #two) setSourcePointer: 0! !

!OBVersionsBrowserTest methodsFor: 'testing' stamp: ''!
testInitialDisplay
	self assertListAt: 1 contains: self expectedHeadings! !

!OBVersionsBrowserTest methodsFor: 'testing' stamp: 'cwp 11/27/2004 21:39'!
testSourceDisplay
	self select: 'BogusA>>two cwp 3/11/2004 20:07'.
	self assertTextIs: self twoLatestVersionText! !

!OBVersionsBrowserTest methodsFor: 'constants' stamp: ''!
twoLatestVersionText
	^  'two
	^ 6' asText makeSelectorBold! !

!OBVersionsBrowserTest methodsFor: 'constants' stamp: ''!
twoSourcePointer
	^ 33555020! !

TestCase subclass: #OBAncestryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBAncestryTest methodsFor: 'asserting' stamp: ''!
assert: ancestor isAncestorOf: descendant
	self assert: (ancestor isAncestorOf: descendant)! !

!OBAncestryTest methodsFor: 'asserting' stamp: ''!
deny: ancestor isAncestorOf: descendant
	self deny: (ancestor isAncestorOf: descendant)! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testClassCategoryIdentity
	self 
		assert: (OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk) 
		isAncestorOf: (OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk).
! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testClassCategoryOther
	self 
		deny: (OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk)
		isAncestorOf: (OBClassCategoryNode on: 'Bogus-Formats' inEnvironment: Smalltalk)
	! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testClassIdentity
	self assert: BogusA asNode isAncestorOf: BogusA asNode! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testClassInClassCategory
	| cat |
	cat := OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk.
	self assert: cat isAncestorOf: BogusA asNode! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testClassInOtherCategory
	| cat |
	cat := OBClassCategoryNode on: 'Bogus-Base' inEnvironment: Smalltalk.
	self deny: cat isAncestorOf: BogusF asNode! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 12:55'!
testClassMethodInClassCat
	self 
		assert: (OBClassCategoryNode on: #'Bogus-Base' inEnvironment: Smalltalk)
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA class)
! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testClassOther
	self deny: BogusB asNode isAncestorOf: BogusA asNode! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 9/24/2005 22:28'!
testClassVarInClass
	self 
		assert: BogusB asNode
		isAncestorOf: (OBInstanceVariableNode 
						on: 'FirstClassVariableB' 
						inClass: BogusB)! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 9/24/2005 22:27'!
testInstVarInClass
	self 
		assert: BogusB asNode
		isAncestorOf: (OBInstanceVariableNode 
						on: 'firstInstanceVariableB' 
						inClass: BogusB)! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testMethodCatIdentity
	self 
		assert: (OBMethodCategoryNode on: #letters inClass: BogusA)
		isAncestorOf: (OBMethodCategoryNode on: #letters inClass: BogusA)! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testMethodCatOther
	self 
		deny: (OBMethodCategoryNode on: #numbers inClass: BogusA)
		isAncestorOf: (OBMethodCategoryNode on: #letters inClass: BogusA)! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testMethodIdentity
	self 
		assert: (OBMethodNode on: #a inClass: BogusA)
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA)! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testMethodInClass
	self assert: BogusA asNode
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA)! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 12:54'!
testMethodInClassCat
	self 
		assert: (OBClassCategoryNode on: #'Bogus-Base' inEnvironment: Smalltalk)
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA)
! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testMethodInMetaclass
	self deny: BogusA asNode
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA class)! !

!OBAncestryTest methodsFor: 'tests' stamp: ''!
testMethodInMethodCat
	self 
		assert: (OBMethodCategoryNode on: #letters inClass: BogusA)
		isAncestorOf: (OBMethodNode on: #a inClass: BogusA)! !

!OBAncestryTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testMethodInOtherClass
	self deny: BogusA asNode
		isAncestorOf: (OBMethodNode on: #isString inClass: BogusE)! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 12/8/2004 21:48'!
testMethodOverride
	self 
		assert: (OBMethodNode on: #isString inClass: BogusA)
		isAncestorOf: (OBMethodNode on: #isString inClass: BogusE).
	! !

!OBAncestryTest methodsFor: 'tests' stamp: 'cwp 2/28/2006 17:32'!
testMethodSiblings
	self 
		deny: (OBMethodNode on: #isString inClass: String)
		isAncestorOf: (OBMethodNode on: #isString inClass: BogusA).
	! !

TestCase subclass: #OBCategoryServantTest
	instanceVariableNames: 'announcer organizer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCategoryServantTest methodsFor: 'emulating' stamp: 'cwp 6/29/2006 00:22'!
announcer
	^ announcer! !

!OBCategoryServantTest methodsFor: 'emulating' stamp: 'cwp 6/25/2006 17:38'!
organization
	^ organizer! !

!OBCategoryServantTest methodsFor: 'emulating' stamp: 'cwp 6/28/2006 00:40'!
requestor
	^ OBRequestor for: self! !

!OBCategoryServantTest methodsFor: 'running' stamp: 'cwp 7/17/2006 13:53'!
setUp
	announcer _ OBAnnouncer new.
! !

OBCategoryServantTest subclass: #OBSortCatSvcTest
	instanceVariableNames: 'service'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSortCatSvcTest methodsFor: 'running' stamp: 'cwp 7/25/2006 16:36'!
setUp
	super setUp.
	service _ OBCategoryServant new svcSortCategories.! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:38'!
test01LabelIsCorrect
	self assert: service label = 'alphabetize categories'! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:40'!
test02HasNoKeystroke
	self assert: service keystroke isNil! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:41'!
test03DoesntWantButton
	self deny: service wantsButton! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:41'!
test04ConditionRejectsClassCatNode
	| requestor |
	requestor _ (self requestor node: (OBClassCategoryNode 
										on: 'Foo' 
										inEnvironment: organizer)).
	self deny: (service isEnabledFor: requestor)! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:42'!
test05ConditionRejectsMethodCatNode

	| requestor |
	requestor _ self requestor node: (OBMethodCategoryNode on: 'tests' inClass: self class).
	self deny: (service isEnabledFor: requestor)! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:42'!
test06ConditionAcceptsEnvironmentNode

	| requestor |
	requestor _ self requestor node: (OBEnvironmentNode on: organizer).
	self assert: (service isEnabledFor: requestor)! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:43'!
test07ConditionAcceptsClassNode

	| requestor |
	requestor _ self requestor node: (OBClassNode on: self class).
	self assert: (service isEnabledFor: requestor)! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 17:51'!
test08ExecutionOnEnvironmentNode
	| requestor |
	organizer _ SystemOrganizer defaultList: #().
	organizer addCategory: 'Bravo'.
	organizer addCategory: 'Alpha'.
	organizer addCategory: 'Delta'.
	self deny: (organizer categories = #('Alpha' 'Bravo' 'Delta')).
	requestor := self requestor node: (OBEnvironmentNode on: self).
	service condExecuteFor: requestor.
	self assert: (organizer categories = #('Alpha' 'Bravo' 'Delta')).! !

!OBSortCatSvcTest methodsFor: 'tests' stamp: 'cwp 7/25/2006 16:50'!
test09ExecutionOnClassNode
	| requestor |
	organizer _ ClassOrganizer defaultList: #().
	organizer 
		addCategory: 'bravo';
		addCategory: 'alpha';
		addCategory: 'delta'.
	self deny: organizer categories = #('alpha' 'bravo' 'delta').
	requestor := self requestor node: (OBClassNode on: self).
	service condExecuteFor: requestor.
	self assert: organizer categories = #('alpha' 'bravo' 'delta')! !

TestCase subclass: #OBCategoryServiceTest
	instanceVariableNames: 'service announcer organizer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCategoryServiceTest class methodsFor: 'as yet unclassified' stamp: 'cwp 9/25/2006 00:27'!
isAbstract
	^ self name == #OBCategoryServantTest! !

!OBCategoryServiceTest class methodsFor: 'as yet unclassified' stamp: 'cwp 9/25/2006 00:27'!
shouldInheritSelectors
	^ true! !

!OBCategoryServiceTest methodsFor: 'emulating' stamp: 'cwp 9/28/2006 09:15'!
announce: anObject
	^ announcer announce: anObject! !

!OBCategoryServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 9/28/2006 09:17'!
announcer
	^ announcer! !

!OBCategoryServiceTest methodsFor: 'emulating' stamp: 'cwp 6/25/2006 17:38'!
organization
	^ organizer! !

!OBCategoryServiceTest methodsFor: 'emulating' stamp: 'cwp 6/28/2006 00:40'!
requestor
	^ OBRequestor for: self! !

!OBCategoryServiceTest methodsFor: 'running' stamp: 'cwp 6/29/2006 00:45'!
setUp
	announcer _ OBAnnouncer new.
	organizer _ SystemOrganizer defaultList: #().
! !

!OBCategoryServiceTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:23'!
test01LabelIsString
	self assert: service label isString! !

!OBCategoryServiceTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:23'!
test02HasCorrectKeystroke
	self assert: service keystroke isNil! !

!OBCategoryServiceTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:23'!
test03DoesntWantButton
	self deny: service wantsButton! !

OBCategoryServiceTest subclass: #OBSvcAutoCategorizeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcAutoCategorizeTest methodsFor: 'running' stamp: 'cwp 9/25/2006 00:25'!
setUp
	super setUp.
	service _ OBSvcAutoCategorize new.! !

!OBSvcAutoCategorizeTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:26'!
test04ConditionRejectsClassCatNode
	| node |
	node _ OBClassCategoryNode 
			on: 'Foo' 
			inEnvironment: self.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcAutoCategorizeTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:28'!
test05ConditionRejectsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcAutoCategorizeTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:30'!
test06ConditionRejectsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: self.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcAutoCategorizeTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:31'!
test07ConditionAcceptsClassNode

	| node |
	node _ OBClassNode on: self class.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcAutoCategorizeTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:36'!
test09Execution
	"Just execute the code to ensure there's nothing horribly
	wrong. Trying to assert that it classifies methods correctly
	would be a pain."

	| node |
	node _ OBClassNode on: self class.
	service executeOn: node for: self requestor.
		
		! !

OBCategoryServiceTest subclass: #OBSvcCreateCatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcCreateCatTest methodsFor: 'support' stamp: 'cwp 9/24/2006 22:37'!
setUp
	super setUp.
	service _ OBSvcCreateCategory new.! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:05'!
test04ConditionRejectsClassCatNode
	| node |
	node _ OBClassCategoryNode 
			on: 'Foo' 
			inEnvironment: self.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:06'!
test05ConditionRejectsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:30'!
test06ConditionAcceptsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: self.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:06'!
test07ConditionAcceptsClassNode

	| node |
	node _ OBClassNode on: self class.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:16'!
test08ExecutionOnEnvironmentNode
	| node |
	node _ OBEnvironmentNode on: self.
	[service executeOn: node for: self requestor] on: OBTextRequest
		do: 
			[:n | 
			self assert: n template = 'Category-Name'.
			n resume: 'Test-Category'].
	self assert: (organizer categories includes: 'Test-Category')! !

!OBSvcCreateCatTest methodsFor: 'tests' stamp: 'cwp 9/25/2006 00:13'!
test09ExecutionOnClassNode
	| node |
	node _ OBClassNode on: self.
	[service executeOn: node for: self requestor] 
		on: OBTextRequest
		do: 
			[:n | 
			self assert: n template = 'Category-Name'.
			n resume: 'Test-Category'].
	self assert: (organizer categories includes: 'Test-Category')! !

OBCategoryServiceTest subclass: #OBSvcRemoveCatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcRemoveCatTest methodsFor: 'emulating' stamp: 'cwp 7/17/2006 13:50'!
removeCategory: aSymbol 
	organizer removeCategory: aSymbol! !

!OBSvcRemoveCatTest methodsFor: 'running' stamp: 'cwp 9/28/2006 08:36'!
setUp
	super setUp.
	service _ OBSvcRemoveCat new! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:36'!
test02HasCorrectKeystroke
	self assert: service keystroke = $x.! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:39'!
test04ConditionAcceptsClassCatNode
	| node |
	node _ OBClassCategoryNode 
			on: 'Foo' 
			inEnvironment: self.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:40'!
test05ConditionAcceptsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:41'!
test06ConditionRejectsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: organizer.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:41'!
test07ConditionRejectsClassNode

	| node |
	node _ OBClassNode on: self class.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:42'!
test08ExecutionOnClassCatNode
	| node |
	organizer _ SystemOrganizer defaultList: #().
	organizer addCategory: 'Some-Category'.
	node _ OBClassCategoryNode 
			on: 'Some-Category' 
			inEnvironment: self.
	service executeOn: node for: self.
	self deny: (organizer categories includes: 'Some-Category')! !

!OBSvcRemoveCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:43'!
test09ExecutionOnMethodCatNode
	| node |
	organizer _ ClassOrganizer defaultList: #().
	organizer addCategory: #category.
	node _ OBMethodCategoryNode
			on: #category 
			inClass: self.
	service executeOn: node for: self.
	self deny: (organizer categories includes: #category)! !

OBCategoryServiceTest subclass: #OBSvcRemoveEmptyCatsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcRemoveEmptyCatsTest methodsFor: 'support' stamp: 'cwp 9/28/2006 08:48'!
setUp
	super setUp.
	service _ OBSvcRemoveEmptyCats new! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:49'!
test04ConditionRejectsClassCatNode
	| node |
	node _ OBClassCategoryNode 
				on: 'Foo' 
				inEnvironment: self.
	self deny: (service isActiveOn: node for: self).! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:49'!
test05ConditionRejectsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:50'!
test06ConditionAcceptsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: self.
	self assert: (service isActiveOn: node for: self).! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:50'!
test07ConditionAcceptsClassNode

	| node |
	node _ OBClassNode on: self class.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:51'!
test08ExecutionOnEnvironmentNode
	| node |
	organizer _ SystemOrganizer defaultList: #().
	organizer addCategory: 'Empty'.
	organizer classify: #'not-a-class-name' under: 'NotEmpty'.
	node _ OBEnvironmentNode on: self.
	service executeOn: node for: self.
	self deny: (organizer categories includes: 'Empty').
	self assert: (organizer categories includes: 'NotEmpty').! !

!OBSvcRemoveEmptyCatsTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:51'!
test09ExecutionOnClassNode
	| node |
	organizer _ ClassOrganizer defaultList: #().
	organizer addCategory: 'Empty'.
	organizer classify: #'not-a-selector' under: 'NotEmpty'.
	node _ OBClassNode on: self.
	service executeOn: node for: self.
	self deny: (organizer categories includes: 'Empty').
	self assert: (organizer categories includes: 'NotEmpty').! !

OBCategoryServiceTest subclass: #OBSvcRenameCatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcRenameCatTest methodsFor: 'emulating' stamp: 'cwp 7/25/2006 17:54'!
removeCategory: aSymbol 
	organizer removeCategory: aSymbol! !

!OBSvcRenameCatTest methodsFor: 'running' stamp: 'cwp 9/28/2006 08:56'!
setUp
	super setUp.
	service _ OBSvcRenameCat new! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:57'!
test04ConditionAcceptsClassCatNode
	| node |
	node _ OBClassCategoryNode 
			on: 'Foo' 
			inEnvironment: self.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:58'!
test05ConditionAcceptsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self assert: (service isActiveOn: node for: self).! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:58'!
test06ConditionRejectsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: self.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 08:59'!
test07ConditionRejectsClassNode

	| node |
	node _ OBClassNode on: self class.
	self deny: (service isActiveOn: node for: self).! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:00'!
test08ExecutionOnClassCatNode
	| node |
	organizer _ SystemOrganizer defaultList: #().
	organizer addCategory: 'Some-Category'.
	node _ OBClassCategoryNode 
				on: 'Some-Category' 
				inEnvironment: self.
	[service executeOn: node for: self] 
		on: OBTextRequest
		do: [:n | 
			self assert: n template = 'Some-Category'.
			n resume: 'Test-Category'].
	self deny: (organizer categories includes: 'Some-Category').
	self assert: (organizer categories includes: 'Test-Category')! !

!OBSvcRenameCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:00'!
test09ExecutionOnMethodCatNode
	| node |
	organizer _ ClassOrganizer defaultList: #().
	organizer addCategory: #category.
	node _ OBMethodCategoryNode
			on: #category 
			inClass: self.
	[service executeOn: node for: self] 
		on: OBTextRequest
		do: [:n | 
			self assert: n template = 'category'.
			n resume: #'new name'].
	self deny: (organizer categories includes: #category).
	self assert: (organizer categories includes: #'new name').! !

OBCategoryServiceTest subclass: #OBSvcReorgCatTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSvcReorgCatTest methodsFor: 'support' stamp: 'cwp 9/28/2006 09:08'!
setUp
	super setUp.
	service _ OBSvcReorgCats new.! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:09'!
test04ConditionRejectsClassCatNode
	| node |
	node _ OBClassCategoryNode 
				on: 'Foo' 
				inEnvironment: organizer.
	self deny: (service isActiveOn: node for: self)! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:09'!
test05ConditionRejectsMethodCatNode

	| node |
	node _ OBMethodCategoryNode on: 'tests' inClass: self class.
	self deny: (service isActiveOn: node for: self).! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:10'!
test06ConditionAcceptsEnvironmentNode

	| node |
	node _ OBEnvironmentNode on: self.
	self assert: (service isActiveOn: node for: self)! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:10'!
test07ConditionAcceptsClassNode

	| node |
	node _ OBClassNode on: self class.
	self assert: (service isActiveOn: node for: self).! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:11'!
test08ExecutionOnEnvironmentNode
	| ann node |
	ann _ nil.
	self announcer 
		observe: OBDefinitionChanged 
		do: [:obj | ann _ obj].
	node _ OBEnvironmentNode on: self.
	service executeOn: node for: self.
	self deny: ann isNil! !

!OBSvcReorgCatTest methodsFor: 'tests' stamp: 'cwp 9/28/2006 09:11'!
test09ExecutionOnClassNode
	| ann node |
	ann _ nil.
	self announcer 
		observe: OBDefinitionChanged 
		do: [:obj | ann _ obj].
	node _ OBClassNode on: self.
	service executeOn: node for: self.
	self deny: ann isNil! !

TestCase subclass: #OBClassCategoryNodeTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBClassCategoryNodeTest methodsFor: 'emulating' stamp: 'cwp 7/8/2006 23:55'!
classNames
	^ #('BravoCharlie' 'AlphaBravoCharlie' 'Bravo' 'AlphaCharlie')! !

!OBClassCategoryNodeTest methodsFor: 'tests' stamp: 'cwp 7/8/2006 23:56'!
testExactMatchFirst
	| name labels |
	name _ 'Bravo'.
	[OBClassCategoryNode findClassIn: self pattern: name]
		on: OBChoiceRequest
		do: [:choice | labels _ choice labels].
	self deny: labels isNil.
	self assert: labels first = name.! !

!OBClassCategoryNodeTest methodsFor: 'tests' stamp: 'cwp 7/9/2006 00:10'!
testExactMatchHasLine
	| name lines |
	name _ 'Bravo'.
	[OBClassCategoryNode findClassIn: self pattern: name]
		on: OBChoiceRequest
		do: [:choice | lines _ choice lines].
	self deny: lines isNil.
	self assert: lines = #(1)! !

!OBClassCategoryNodeTest methodsFor: 'emulating' stamp: 'cwp 7/14/2006 14:47'!
traitNames
	^ #()! !

TestCase subclass: #OBClassDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBClassDefinitionTest commentStamp: 'cwp 2/28/2005 23:31' prior: 0!
Right now, OBClassDefinition is mostly covered by the browser tests. Eventually those tests should be moved here,!

!OBClassDefinitionTest methodsFor: 'tests' stamp: 'cwp 2/28/2005 23:33'!
testDoItReceiverClass
	| definition |
	definition _ OBClassDefinition environment: Smalltalk template: BogusA definition.
	self deny: definition doItReceiver isMeta.
	! !

TestCase subclass: #OBClassHierarchyTest
	instanceVariableNames: 'classes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBClassHierarchyTest methodsFor: 'constants' stamp: 'cwp 12/11/2004 00:13'!
bogusA
	^ self nodeForClassNamed: #BogusA! !

!OBClassHierarchyTest methodsFor: 'constants' stamp: 'cwp 12/11/2004 00:13'!
bogusB
	^ self nodeForClassNamed: #BogusB! !

!OBClassHierarchyTest methodsFor: 'constants' stamp: 'cwp 12/11/2004 00:29'!
bogusE
	^ self nodeForClassNamed: #BogusE! !

!OBClassHierarchyTest methodsFor: 'constants' stamp: 'cwp 12/11/2004 00:12'!
nodeForClassNamed: aSymbol
	^ classes detect: [:ea | ea theClassName = aSymbol]! !

!OBClassHierarchyTest methodsFor: 'running' stamp: 'cwp 12/12/2004 22:24'!
setUp
	| metacat cat |
	metacat := OBMetaNode new childAt: #classesHierarchically
				put: (OBMetaNode new displaySelector: #name).
	cat := OBClassCategoryNode on: BogusInfo baseCategory
				inEnvironment: BogusInfo environment.
	classes := metacat nodesForParent: cat! !

!OBClassHierarchyTest methodsFor: 'tests' stamp: 'cwp 12/11/2004 00:11'!
testAB
	self assert: (classes indexOf: self bogusA) < (classes indexOf: self bogusB)! !

!OBClassHierarchyTest methodsFor: 'tests' stamp: 'cwp 12/11/2004 00:33'!
testAE
	self assert: (classes indexOf: self bogusA) < (classes indexOf: self bogusE)! !

!OBClassHierarchyTest methodsFor: 'tests' stamp: 'cwp 12/11/2004 00:29'!
testEB
	self assert: (classes indexOf: self bogusE) < (classes indexOf: self bogusB)! !

TestCase subclass: #OBCodeBrowserUiTest
	instanceVariableNames: 'browser'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCodeBrowserUiTest methodsFor: 'running' stamp: 'cwp 12/6/2004 22:11'!
setUp
	browser _ OBSystemBrowser new.
	browser addDependent: self.
	! !

!OBCodeBrowserUiTest methodsFor: 'running' stamp: 'cwp 12/6/2004 22:11'!
tearDown
	browser removeDependent: self! !

!OBCodeBrowserUiTest methodsFor: 'tests' stamp: 'cwp 6/3/2006 19:41'!
testWindowMenu
	| menu |
	(Smalltalk includesKey: #SystemBrowser) ifFalse: [^ self].
	menu _ MenuMorph new.
	browser addModelItemsToWindowMenu: menu.
	self deny: (menu itemWithWording: 'Register this Browser as default') isNil.
	self deny: (menu itemWithWording: 'Choose new default browser') isNil
		! !

TestCase subclass: #OBCodeNodeEqualityTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:47'!
testClassCategoryEquality
	self assert: (OBClassCategoryNode on: #'Bogus-Base' inEnvironment: Smalltalk)
					=  (OBClassCategoryNode on: #'Bogus-Base' inEnvironment: Smalltalk)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:48'!
testClassCategoryInequality
	self deny: (OBClassCategoryNode on: #'Bogus-Base' inEnvironment: Smalltalk)
					=  (OBClassCategoryNode on: #'Bogus-Formats' inEnvironment: Smalltalk)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 22:21'!
testClassCommentEquality
	self assert: (OBClassCommentNode on: BogusA)
					= (OBClassCommentNode on: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 22:23'!
testClassCommentInequality
	self deny: (OBClassCommentNode on: BogusA)
					= (OBClassCommentNode on: BogusB)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:14'!
testClassEquality
	self assert: BogusA asNode = BogusA asNode! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'dvf 8/31/2005 13:17'!
testClassInequality
	self deny: BogusA asNode = BogusB asNode! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:39'!
testMethod
	self assert: (OBMethodNode on: #one inClass: BogusA)
					= (OBMethodNode on: #one inClass: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:46'!
testMethodCategoryEquality
	self assert: (OBMethodCategoryNode on: #numbers inClass: BogusA)
					= (OBMethodCategoryNode on: #numbers inClass: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:46'!
testMethodCategoryInequality1
	self deny: (OBMethodCategoryNode on: #numbers inClass: BogusA)
					= (OBMethodCategoryNode on: #letters inClass: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:47'!
testMethodCategoryInequality2
	self deny: (OBMethodCategoryNode on: #numbers inClass: BogusA)
					= (OBMethodCategoryNode on: #numbers inClass: BogusB)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:45'!
testMethodEquality
	self assert: (OBMethodNode on: #one inClass: BogusA)
					= (OBMethodNode on: #one inClass: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:45'!
testMethodInequality1
	self deny: (OBMethodNode on: #one inClass: BogusA)
					= (OBMethodNode on: #two inClass: BogusA)! !

!OBCodeNodeEqualityTest methodsFor: 'tests' stamp: 'cwp 12/20/2004 00:46'!
testMethodInequality2
	self deny: (OBMethodNode on: #one inClass: BogusA)
					= (OBMethodNode on: #one inClass: BogusB)! !

TestCase subclass: #OBCodeSanityCheckTest
	instanceVariableNames: 'node'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBCodeSanityCheckTest methodsFor: 'constants' stamp: ''!
bogusARedefinition
	^ BogusA definition! !

!OBCodeSanityCheckTest methodsFor: 'constants' stamp: ''!
bogusCDefinition
	^ 'Object subclass: #BogusC
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''', BogusInfo baseCategory, ''''! !

!OBCodeSanityCheckTest methodsFor: 'callbacks' stamp: ''!
selectionInterval
	^ 1 to: 0! !

!OBCodeSanityCheckTest methodsFor: 'testing' stamp: ''!
testClassCreation
	node := OBClassCategoryNode on: BogusInfo baseCategory inEnvironment: Smalltalk.
	self 
		should: [node definition accept: self bogusCDefinition notifying: self]
		raise: OBConfirmationRequest! !

!OBCodeSanityCheckTest methodsFor: 'testing' stamp: 'dvf 8/31/2005 13:17'!
testClassDefinition
	node := BogusA asNode.
	self 
		should: [node definition accept: self bogusCDefinition notifying: self]
		raise: OBConfirmationRequest! !

!OBCodeSanityCheckTest methodsFor: 'testing' stamp: 'dvf 8/31/2005 13:17'!
testClassRedefinition
	node := BogusA asNode.
	self shouldnt: [node accept: self bogusARedefinition notifying: self]
		raise: OBConfirmationRequest! !

!OBCodeSanityCheckTest methodsFor: 'callbacks' stamp: ''!
text
	^ node text asText! !

TestCase subclass: #OBMethodDefinitionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBMethodDefinitionTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/28/2005 23:45'!
testDoItReceiverCategory
	| panel |
	panel _ OBMethodDefinition inCategory: #letters inClass: BogusA.
	self deny: panel doItReceiver isMeta! !

!OBMethodDefinitionTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/28/2005 23:49'!
testDoItReceiverClassMethod
	| panel |
	panel _ OBMethodDefinition
				source: (BogusA class sourceCodeAt: #a)
				inClass: BogusA class.
	self deny: panel doItReceiver isMeta! !

!OBMethodDefinitionTest methodsFor: 'as yet unclassified' stamp: 'cwp 2/28/2005 23:48'!
testDoItReceiverInstMethod
	| panel |
	panel _ OBMethodDefinition
				source: (BogusA sourceCodeAt: #one)
				inClass: BogusA.
	self deny: panel doItReceiver isMeta! !

TestCase subclass: #OBMethodVersionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBMethodVersionTest methodsFor: 'constants' stamp: ''!
fakeSourceFileArray
	^ OBSourceFilesResource current sources! !

!OBMethodVersionTest methodsFor: 'constants' stamp: ''!
methodReference
	| ref |
	ref := MethodReference new.
	ref setStandardClass: self class methodSymbol: #testScanFromMethodRef.
	^ ref! !

!OBMethodVersionTest methodsFor: 'testing' stamp: ''!
testScanFromMethodRef
	| changes |
	changes := OBMethodVersion versionsOfMethod: self methodReference.
	self deny: changes isEmpty! !

!OBMethodVersionTest methodsFor: 'testing' stamp: ''!
testScanFromPointer
	| changes sourcePointer sources |
	sources :=  self fakeSourceFileArray.
	sourcePointer := sources sourcePointerFromFileIndex: 2 andPosition: 488.
	changes := OBMethodVersion scan: sources from: sourcePointer.
	self assert: changes size = 6.
	changes do: [:ea | 
					self assert: ea theClassName = #BogusA.
					self assert: ea category = 'as yet unclassified'.
					self assert: (ea stamp beginsWith: 'cwp 3/11/2004 20:0')]! !

!OBMethodVersionTest methodsFor: 'testing' stamp: ''!
testScanFromPointerToClassMethod
	| changes sourcePointer sources |
	sources :=  self fakeSourceFileArray.
	sourcePointer := sources sourcePointerFromFileIndex: 2 andPosition: 694.
	changes := OBMethodVersion scan: sources from: sourcePointer.
	self assert: changes size = 2.
	changes do: [:ea | 
					self assert: ea theClassName = #'BogusA class'.
					self assert: ea category = 'as yet unclassified'.
					self assert: (ea stamp beginsWith: 'cwp 3/11/2004 20:0')]! !

TestCase subclass: #OBSystemBrowserAdaptorTest
	instanceVariableNames: 'oldDefault browser registry'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSystemBrowserAdaptorTest methodsFor: 'running' stamp: 'cwp 12/5/2004 21:58'!
openWith: aBlock
	aBlock
		on: OBBrowseRequest
		do: [:n | browser _ n browser].
	self deny: browser isNil.
! !

!OBSystemBrowserAdaptorTest methodsFor: 'running' stamp: 'cwp 6/3/2006 19:25'!
setUp
	registry _ Smalltalk at: #SystemBroser ifAbsent: [nil].
	registry ifNotNil:
		[oldDefault _ registry defaultOrNil.
		registry default: OBSystemBrowserAdaptor]! !

!OBSystemBrowserAdaptorTest methodsFor: 'running' stamp: 'cwp 6/3/2006 19:28'!
tearDown
	registry ifNotNil: [registry default: oldDefault]! !

!OBSystemBrowserAdaptorTest methodsFor: 'testing' stamp: 'cwp 6/3/2006 19:27'!
testDefaultOpenBrowser
	registry ifNil: [^ self].
	self openWith: [registry defaultOpenBrowser].
	self assert: browser currentNode isNil! !

!OBSystemBrowserAdaptorTest methodsFor: 'testing' stamp: 'cwp 6/3/2006 19:27'!
testFullOnClassSelector
	registry ifNil: [^ self].
	self openWith: [Browser fullOnClass: BogusA selector: #one].
	self assert: browser currentNode theClass = BogusA.
	self assert: browser currentNode selector = #one! !

TestCase subclass: #OBTextCmdTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBTextCmdTest methodsFor: 'emulating' stamp: 'cwp 4/18/2006 21:10'!
announcer
	^ OBAnnouncer new! !

!OBTextCmdTest methodsFor: 'asserting' stamp: 'cwp 9/24/2005 00:10'!
assertPanel: actionBlock browser: assertionBlock
	| notification panel |
	panel := OBDefinitionPanel inBrowser: self.
	[self assert: (actionBlock value: panel)]
		on: OBBrowseRequest
		do: [:ex | notification := ex].
	self deny: notification isNil.
	self assert: (assertionBlock value: notification browser)! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:30'!
testBrowseItWithClass
	self
		assertPanel: [:p | p browseIt: #BogusA]
		browser: [:browser | browser currentNode theClass = BogusA]! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:31'!
testBrowseItWithGlobal
	self
		assertPanel: [:p | p browseIt: #Transcript]
		browser: [:browser | browser currentNode theClass = TranscriptStream]
! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:32'!
testBrowseItWithSelector
	self
		assertPanel: [:p | p browseIt: #testBrowseItWithSelector]
		browser: [:browser | browser root selector = #testBrowseItWithSelector]! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:35'!
testImpementorsOfIt
	self
		assertPanel: [:p | p implementorsOfIt: #testBrowseItWithSelector]
		browser: [:browser | browser root selector = #testBrowseItWithSelector]! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:43'!
testReferencesToIt
	self
		assertPanel: [:p | p referencesToIt: #BogusA]
		browser: [:browser | browser root theClass = BogusA]! !

!OBTextCmdTest methodsFor: 'tests' stamp: 'cwp 10/31/2004 01:36'!
testSendersOfIt
	self
		assertPanel: [:p | p sendersOfIt: #testBrowseItWithSelector]
		browser: [:browser | browser root selector = #testBrowseItWithSelector]! !

OBOpenTest subclass: #OBStandardOpenTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBStandardOpenTest methodsFor: 'tests' stamp: 'avi 9/17/2005 01:29'!
testListBrowseRoot
	self open: [OBSendersBrowser browseRoot: (OBMethodNode on: #one inClass: BogusA)].
	self assert: browser navigationPanel minPanes = 1.
	self assert: browser navigationPanel maxPanes = 2.
	self assert: browser currentNode isNil! !

!OBStandardOpenTest methodsFor: 'tests' stamp: 'avi 9/17/2005 01:37'!
testListBrowseRootTitle
	self open: [OBSendersBrowser 
				browseRoot: (OBMethodNode on: #one inClass: BogusA)
				title: 'My senders of'].
	self assert: browser navigationPanel minPanes = 1.
	self assert: browser navigationPanel maxPanes = 2.
	self assert: browser currentNode isNil.
	self assert: browser defaultLabel = 'My senders of #one'! !

!OBStandardOpenTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 17:44'!
testSystemOpen
	self open: [OBSystemBrowser open].
	self assert: browser navigationPanel minPanes = 4.
	self assert: browser navigationPanel maxPanes = 4.
	self assert: browser currentNode = nil! !

!OBStandardOpenTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 18:31'!
testSystemOpenOnClass
	self open: [OBSystemBrowser openOnClass: BogusA].
	self assert: browser navigationPanel minPanes = 4.
	self assert: browser navigationPanel maxPanes = 4.
	self assert: browser currentNode name = #BogusA! !

!OBStandardOpenTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 17:44'!
testSystemOpenOnClassSelector
	self open: [OBSystemBrowser openOnClass: BogusA selector: #one].
	self assert: browser navigationPanel minPanes = 4.
	self assert: browser navigationPanel maxPanes = 4.
	self assert: browser currentNode name = #one! !

!OBStandardOpenTest methodsFor: 'tests' stamp: 'cwp 12/5/2004 17:52'!
testVersionsOpenOn
	| root |
	root _ OBMethodNode on: #testVersionsOpenOn inClass: self class.
	self open: [OBVersionBrowser openOn: root].
	self assert: browser navigationPanel minPanes = 1.
	self assert: browser navigationPanel maxPanes = 1.
	self assert: browser currentNode isNil.
	self assert: browser root = root! !

TestResource subclass: #OBBrowserResource
	instanceVariableNames: 'model morph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBBrowserResource methodsFor: 'accessing' stamp: ''!
model
	^ model! !

!OBBrowserResource methodsFor: 'accessing' stamp: ''!
morph
	^ morph! !

!OBBrowserResource methodsFor: 'running' stamp: 'cwp 12/5/2004 18:13'!
setUp
	model := OBBrowser metaNode: self metagraph node: self node.
	model addPanel: (OBDefinitionPanel inBrowser: model).
	morph := model morph.! !

OBBrowserResource subclass: #OBImageBrowserResource
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBImageBrowserResource methodsFor: 'running' stamp: 'avi 9/17/2005 01:13'!
metagraph
	^ OBSystemBrowser alphabeticalMetaNode! !

!OBImageBrowserResource methodsFor: 'running' stamp: ''!
node
	^ OBEnvironmentNode forImage! !

TestResource subclass: #OBSourceFilesResource
	instanceVariableNames: 'sources'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'OB-Tests-Standard'!

!OBSourceFilesResource methodsFor: 'initializing' stamp: ''!
changesStream
	^ ReadStream on: self changesString! !

!OBSourceFilesResource methodsFor: 'initializing' stamp: ''!
changesString
	^ '!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:05'' prior: 16777764!!
one
	^ 4!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06'' prior: 16777864!!
two
	^ 4!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06'' prior: 33554520!!
one
	^ 5!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06'' prior: 33554620!!
two
	^ 5!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:07'' prior: 33554720!!
one
	^ 6!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:07'' prior: 33554820!!
two
	^ 6!! !!
!!BogusA class methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:07'' prior: 16777462!!
three
	^ 2!! !!'! !

!OBSourceFilesResource methodsFor: 'initializing' stamp: ''!
setUp
	sources := StandardSourceFileArray new: 2.
	sources at: 1 put: self sourceStream.
	sources at: 2 put: self changesStream.! !

!OBSourceFilesResource methodsFor: 'initializing' stamp: ''!
sourceStream
	^ ReadStream on: self sourceString! !

!OBSourceFilesResource methodsFor: 'initializing' stamp: ''!
sourceString
	^ '!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:05''!!
one
	^ 1!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06''!!
two
	^ 1!! !!
!!BogusA class methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06''!!
three
	^ 1!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06'' prior: 16777288!!
one
	^ 2!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:06'' prior: 16777372!!
two
	^ 2!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:07'' prior: 16777600!!
one
	^ 3!! !!
!!BogusA methodsFor: ''as yet unclassified'' stamp: ''cwp 3/11/2004 20:07'' prior: 16777664!!
two
	^ 3!! !!'! !

!OBSourceFilesResource methodsFor: 'accessing' stamp: ''!
sources
	^ sources! !
